Revert the decoders change in the previous commit for the time being. While

testing 1.2.6 I encountered a stack overflow in Xine-lib I had not experienced
with earlier testing; happens when decoding AAC. Possibly related to additional
multi-threaded decoding changes made in 1.2.6 but since this wasn't a high
priority change it can wait.

ok ajacoutot@
This commit is contained in:
brad 2014-07-13 17:02:59 +00:00
parent 5f66dd2081
commit 40d9e15975
4 changed files with 22 additions and 54 deletions

View File

@ -1,4 +1,4 @@
# $OpenBSD: Makefile,v 1.114 2014/07/12 21:55:35 brad Exp $
# $OpenBSD: Makefile,v 1.115 2014/07/13 17:02:59 brad Exp $
SHARED_ONLY= Yes
@ -9,7 +9,7 @@ CATEGORIES= multimedia
MASTER_SITES= ${MASTER_SITE_SOURCEFORGE:=xine/}
EXTRACT_SUFX= .tar.xz
REVISION= 4
REVISION= 5
SHARED_LIBS= xine 31.0
@ -21,18 +21,22 @@ MAINTAINER= Brad Smith <brad@comstyle.com>
PERMIT_PACKAGE_CDROM= patents
PERMIT_PACKAGE_FTP= Yes
WANTLIB= FLAC GL GLU ICE SDL SM X11 Xext Xinerama Xv XvMCW avcodec \
avformat avutil bluray c cdio dvdnav dvdread expat fontconfig \
freetype iso9660 jpeg m mad modplug mpcdec mng ogg postproc \
pthread pthread-stubs sndio speex theora usbhid vcdinfo vorbis \
vpx>=5 wavpack xcb-shape xcb-shm xcb-xv xcb xdg-basedir xml2 z
WANTLIB= FLAC GL GLU ICE SDL SM X11 Xext Xinerama Xv XvMCW a52 avcodec \
avformat avutil bluray c cdio dca dvdnav dvdread expat faad \
fontconfig freetype iso9660 jpeg m mad modplug mpcdec mng ogg \
postproc pthread pthread-stubs sndio speex theora usbhid vcdinfo \
vorbis vpx>=5 wavpack xcb-shape xcb-shm xcb-xv xcb xdg-basedir \
xml2 z
XINEAPI_REV= 2.4
SUBST_VARS+= XINEAPI_REV
MODULES= devel/gettext
LIB_DEPENDS= audio/flac \
LIB_DEPENDS= audio/faad \
audio/flac \
audio/liba52 \
audio/libcdio \
audio/libdca \
audio/libmad \
audio/libmodplug \
audio/libogg \
@ -62,10 +66,7 @@ USE_LIBTOOL= gnu
USE_GROFF= Yes
CONFIGURE_STYLE= autoconf
AUTOCONF_VERSION= 2.69
CONFIGURE_ARGS+=--disable-a52dec \
--disable-aalib \
--disable-dts \
--disable-faad \
CONFIGURE_ARGS+=--disable-aalib \
--disable-gdkpixbuf \
--disable-gnomevfs \
--disable-optimizations \

View File

@ -1,26 +0,0 @@
$OpenBSD: patch-src_combined_ffmpeg_ff_audio_decoder_c,v 1.8 2014/07/12 21:55:35 brad Exp $
Enable parser for AC3, DTS, AAC.
--- src/combined/ffmpeg/xine_audio.list.orig Wed Feb 26 10:49:10 2014
+++ src/combined/ffmpeg/xine_audio.list Fri Jun 6 19:54:13 2014
@@ -41,14 +41,16 @@ FLVADPCM ADPCM_SWF Flash ADPCM
WAVPACK WAVPACK WavPack
AMR_NB AMR_NB AMR narrow band
AMR_WB AMR_WB AMR wide band
+A52 AC3 AC-3
EAC3 EAC3 E-AC-3
AAC AAC MPEG4
+++ src/combined/ffmpeg/xine_audio.list Sat Jul 12 20:15:14 2014
@@ -46,6 +46,7 @@ AAC AAC MPEG4
AAC_LATM AAC_LATM AAC LATM
ADPCM_G726 ADPCM_G726 ADPCM G726
QCLP QCELP QualComm Purevoice
+OPUS OPUS Opus Audio
+DTS DTS DTS
# disabled codecs (ref. configure.ac)
-! AC3
! ADPCM_ADX
! ADPCM_G726
! DSICINAUDIO
! AC3

View File

@ -1,4 +1,4 @@
@comment $OpenBSD: PLIST,v 1.21 2014/07/12 21:55:35 brad Exp $
@comment $OpenBSD: PLIST,v 1.22 2014/07/13 17:02:59 brad Exp $
@conflict xine-lib-arts-*
@conflict xine-lib-esd-*
@conflict xine-lib-jack-*
@ -70,8 +70,11 @@ lib/xine/plugins/${XINEAPI_REV}/post/xineplug_post_visualizations.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_ao_out_file.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_ao_out_none.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_ao_out_sndio.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_a52.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_bitplane.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_dts.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_dvaudio.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_faad.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_ff.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_gsm610.so
lib/xine/plugins/${XINEAPI_REV}/xineplug_decode_libjpeg.so
--- src/combined/ffmpeg/ff_audio_decoder.c.orig Wed Feb 26 10:49:10 2014
+++ src/combined/ffmpeg/ff_audio_decoder.c Thu Jun 12 05:12:13 2014
@@ -196,14 +196,17 @@ static void ff_audio_init_codec(ff_audio_decoder_t *th
this->context->codec_type = this->codec->type;
this->context->codec_tag = _x_stream_info_get(this->stream, XINE_STREAM_INFO_AUDIO_FOURCC);
/* Use parser for EAC3, AAC LATM and MPEG.
* Fixes:
* - DVB streams where multiple AAC LATM frames are packed to single PES
* - DVB streams where MPEG audio frames do not follow PES packet boundaries
*/
#if AVPARSE > 1
- if (codec_type == BUF_AUDIO_AAC_LATM ||
+ if (codec_type == BUF_AUDIO_AAC ||
+ codec_type == BUF_AUDIO_AAC_LATM ||
+ codec_type == BUF_AUDIO_A52 ||
codec_type == BUF_AUDIO_EAC3 ||
+ codec_type == BUF_AUDIO_DTS ||
codec_type == BUF_AUDIO_MPEG) {
xprintf (this->stream->xine, XINE_VERBOSITY_DEBUG,

View File

@ -1,24 +1,14 @@
$OpenBSD: patch-src_combined_ffmpeg_xine_audio_list,v 1.2 2014/07/12 21:55:35 brad Exp $
$OpenBSD: patch-src_combined_ffmpeg_xine_audio_list,v 1.3 2014/07/13 17:02:59 brad Exp $
Enable Opus, AC3 and DTS decoder.
@@ -196,14 +196,17 @@ static void ff_audio_init_codec(ff_audio_decoder_t *th
this->context->codec_type = this->codec->type;
this->context->codec_tag = _x_stream_info_get(this->stream, XINE_STREAM_INFO_AUDIO_FOURCC);
- /* Use parser for EAC3, AAC LATM and MPEG.
+ /* Use parser for AC3, EAC3, DTS, AAC, AAC LATM and MPEG.
* Fixes:
* - DVB streams where multiple AAC LATM frames are packed to single PES
Enable Opus decoder.